summaryrefslogtreecommitdiffstats
path: root/kjsembed/builtins/qfile_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/builtins/qfile_imp.h')
-rw-r--r--kjsembed/builtins/qfile_imp.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kjsembed/builtins/qfile_imp.h b/kjsembed/builtins/qfile_imp.h
index bf4df5ea..6db9b2df 100644
--- a/kjsembed/builtins/qfile_imp.h
+++ b/kjsembed/builtins/qfile_imp.h
@@ -9,7 +9,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
-class TQFile;
+class TTQFile;
/**
* Namespace containing the KJSEmbed library.
@@ -17,11 +17,11 @@ class TQFile;
namespace KJSEmbed {
/**
* Wrapper class for TQFile methods.
*
* @author Richard Moore, rich@kde.org
*/
-class QFileImp : public JSProxyImp
+class TQFileImp : public JSProxyImp
{
public:
/** Enumerates the constructors supported by this class. */
@@ -67,19 +67,19 @@ public:
Method_Last = -1
};
- QFileImp( KJS::ExecState *exec, int id, bool constructor=false );
- ~QFileImp();
+ TQFileImp( KJS::ExecState *exec, int id, bool constructor=false );
+ ~TQFileImp();
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TQFile *toQFile( KJS::Object &object );
+ static TTQFile *toTQFile( KJS::Object &object );
//
// Constructors implemented by this class.
//
- KJS::Object QFile_1( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QFile_2( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQFile_1( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQFile_2( KJS::ExecState *exec, const KJS::List &args );
//
// Methods implemented by this class.
@@ -132,7 +132,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TQFile *instance; // Temp
+ TTQFile *instance; // Temp
int id;
bool cons;
};
@@ -17,11 +17,11 @@ class TQFile;
namespace KJSEmbed {
/**
- * Wrapper class for TQFile methods.
+ * Wrapper class for TTQFile methods.
*
* @author Richard Moore, rich@kde.org